﻿//
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

using System;
using System.Security.Cryptography;

namespace Trade.Utility
{
    public class Cryptography
    {
        // Create a salt value using a cryptographic random number generator
        public static byte[] CreateSalt()
        {
            byte[] salt = new byte[32];
            RNGCryptoServiceProvider.Create().GetBytes(salt);
            return salt;
        }

        // Calculate the SHA256 hash of the plain text value and the salt value.
        public static byte[] GetSaltedHash(byte[] plainText, byte[] salt)
        {
            // Combine the plain text and salt values before calculating the hash
            byte[] saltedText = new byte[plainText.Length + salt.Length];
            System.Buffer.BlockCopy(plainText, 0, saltedText, 0, plainText.Length);
            System.Buffer.BlockCopy(salt, 0, saltedText, plainText.Length, salt.Length);

            // Create the SHA256Managed class and calculate the hash value 
            SHA256Managed sha256 = new SHA256Managed();
            return sha256.ComputeHash(saltedText);
        }
    }
}
