﻿//
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

using System;
using System.Web.Security;
//using System.Threading;
using Trade.PassiveStsModelClasses;
using Trade.PassiveStsImplementation;
using Trade.Utility;

namespace Trade.PassiveStsWeb
{
    public partial class Login : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!string.IsNullOrEmpty(txtUserName.Text))
            {
                AccountDataModel account = null;

                try
                {
                    // Validate the username and password
                    StsClient client = new StsClient();
                    account = client.login(txtUserName.Text, txtPassword.Text);
                }
                catch (Exception ex)
                {
                    if (ex.Message.Contains(StockTraderUtility.EXCEPTION_WEBSPHERE_USERID_NOTFOUND))
                        account = null;
                    else
                        throw;
                }

                if (account == null)
                {
                    InvalidLoginMessage.Text = StockTraderUtility.EXCEPTION_MESSAGE_INVALID_LOGIN;
                }
                else
                {
                    Session["UserInfo"] = account;

                    if (Request.QueryString["ReturnUrl"] != null)
                    {
                        FormsAuthentication.SetAuthCookie(txtUserName.Text, false);
                        Response.Redirect(Request.QueryString["ReturnUrl"]);
                    }
                    else
                    {
                        FormsAuthentication.SetAuthCookie(txtUserName.Text, false);
                        Response.Redirect("default.aspx");
                        
                    }
                }
            }
        }
    }
}