//
// Licensed to the Apache Software Foundation (ASF) under one or more
// contributor license agreements.  See the NOTICE file distributed with
// this work for additional information regarding copyright ownership.
// The ASF licenses this file to You under the Apache License, Version 2.0
// (the "License"); you may not use this file except in compliance with
// the License.  You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//

//  .NET StockTrader Sample WCF Application for Benchmarking, Performance Analysis and Design Considerations for Service-Oriented Applications

using System;
using System.Collections.Generic;
using System.Text;
using Trade.StockTraderWebApplicationSettings;

namespace Trade.StockTraderWebApplicationModelClasses
{
    /// <summary>
    /// Model class for displaying special/augmented holding data in a web page.
    /// </summary>
    public sealed class TotalHoldingsUI
    {
        private List<HoldingDataUI> _holdings;
        private decimal _gain;
        private decimal _marketValue;
        private decimal _basis;
        private int _uniqueStockCount;
        private int _totalHoldingsCount;

        public TotalHoldingsUI()
        {
        }

        public TotalHoldingsUI(List<HoldingDataUI>holdings, decimal marketValue, decimal basis, decimal gain)
        {
            this._holdings = holdings;
            this._gain = gain;
            this._marketValue = marketValue;
            this._basis = basis;
        }

        public TotalHoldingsUI(List<HoldingDataUI> holdings, decimal marketValue, decimal basis, decimal gain, int uniqueStockCount, int totalHoldingsCount)
        {
            this._holdings = holdings;
            this._gain = gain;
            this._marketValue = marketValue;
            this._basis = basis;
            this._uniqueStockCount = uniqueStockCount;
            this._totalHoldingsCount = totalHoldingsCount;
        }

        public List<HoldingDataUI> holdings
        {
            get
            {
                return _holdings;
            }
        }

        public decimal marketValue
        {
            get
            {
                return _marketValue;
            }
        }

        public decimal gain
        {
            get
            {
                return _gain;
            }
        }

        public decimal basis
        {
            get
            {
                return _basis;
            }

            set
            {
                this._basis = value;
            }
        }

        public int uniqueStockCount
        {
            get
            {
                return _uniqueStockCount;
            }

            set
            {
                this._uniqueStockCount = value;
            }
        }

        public int totalHoldingsCount
        {
            get
            {
                return _totalHoldingsCount;
            }

            set
            {
                this._totalHoldingsCount = value;
            }
        }
        
        public string gainWithArrow
        {
            get
            {
                return DataFormatHelper.NumberWithStyledArrow(this._gain);
            }
        }
    }
}