/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader;

import java.math.BigDecimal;
import java.util.Calendar;

/**
 * This class is to be used as the data model for order information.
 */
public class CustomOrderBean {

	private static final long serialVersionUID = 5294153874232419015L;

	int accountId;
	int holdingId;

    protected Integer orderID;
    protected String orderType;
    protected String orderStatus;
    protected Calendar openDate;
    protected Calendar completionDate;
    protected Double quantity;
    protected BigDecimal price;
    protected BigDecimal orderFee;
    protected String symbol;

//	public CustomOrderBean(OrderDataBean orderDataBean) {
//		setCompletionDate(orderDataBean.getCompletionDate());
//		setOpenDate(orderDataBean.getOpenDate());
//		setOrderFee(orderDataBean.getOrderFee());
//		setOrderID(orderDataBean.getOrderID());
//		setOrderStatus(orderDataBean.getOrderStatus());
//		setOrderType(orderDataBean.getOrderType());
//		setPrice(orderDataBean.getPrice());
//		setQuantity(orderDataBean.getQuantity());
//		setSymbol(orderDataBean.getSymbol());
//	}

	public CustomOrderBean(int orderId, String orderType, String orderStatus,
			Calendar openDate, Calendar completionDate, double quantity,
			BigDecimal price, BigDecimal orderFee, String symbol) {
		setOrderID(orderId);
		setOrderType(orderType);
		setOrderStatus(orderStatus);
		setOpenDate(openDate);
		setCompletionDate(completionDate);
		setQuantity(quantity);
		setPrice(price);
		setOrderFee(orderFee);
		setSymbol(symbol);
	}

	/**
	 * Constructs data instance for order information.
	 * 
	 * @param accountId
	 *            the account ID of the buyer or seller
	 * @param holdingId
	 *            the ID of corresponding holding of the order
	 */
	public CustomOrderBean(int accountId, int holdingId) {
		this.accountId = accountId;
		this.holdingId = holdingId;
	}

	public int getAccountId() {
		return accountId;
	}

	public void setAccountId(int accountId) {
		this.accountId = accountId;
	}

	public int getHoldingId() {
		return holdingId;
	}

	public void setHoldingId(int holdingId) {
		this.holdingId = holdingId;
	}

    public Integer getOrderID() {
        return orderID;
    }

    public void setOrderID(Integer orderID) {
        this.orderID = orderID;
    }

    public String getOrderType() {
        return orderType;
    }

    public void setOrderType(String orderType) {
        this.orderType = orderType;
    }

    public String getOrderStatus() {
        return orderStatus;
    }

    public void setOrderStatus(String orderStatus) {
        this.orderStatus = orderStatus;
    }

    public Calendar getOpenDate() {
        return openDate;
    }

    public void setOpenDate(Calendar openDate) {
        this.openDate = openDate;
    }

    public Calendar getCompletionDate() {
        return completionDate;
    }

    public void setCompletionDate(Calendar completionDate) {
        this.completionDate = completionDate;
    }

    public Double getQuantity() {
        return quantity;
    }

    public void setQuantity(Double quantity) {
        this.quantity = quantity;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public BigDecimal getOrderFee() {
        return orderFee;
    }

    public void setOrderFee(BigDecimal orderFee) {
        this.orderFee = orderFee;
    }

    public String getSymbol() {
        return symbol;
    }

    public void setSymbol(String symbol) {
        this.symbol = symbol;
    }
}
