/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
 
 package org.apache.stonehenge.stocktrader.services;

import org.apache.stonehenge.stocktrader.dal.ConfigServiceDAO;
import org.apache.stonehenge.stocktrader.dal.DAOFactory;
import org.datacontract.schemas._2004._07.trade.*;
import org.tempuri.ConfigServiceService;
import traderconfighost.trade.*;

import javax.jws.WebParam;
import javax.jws.WebService;
import java.util.List;

@WebService(endpointInterface = "org.tempuri.ConfigServiceService")
public class ConfigServiceServiceImpl implements ConfigServiceService {
    private final DAOFactory facotry;

    public ConfigServiceServiceImpl() {
        facotry = DAOFactory.getFacotry();
    }

    public ConfigServiceDAO getConfigServiceDAO() {
        return facotry.getConfigServiceDAO();
    }

    public GetClientConfigResponse getClientConfig(
            @WebParam(name = "GetClientConfig", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") GetClientConfig getClientConfig) {
        GetClientConfigResponse clientConfigResponse = new GetClientConfigResponse();
        String clientName = getClientConfig.getClient().getClientName();
        ClientConfigResponse config = getConfigServiceDAO().getClientConfig(clientName);
        clientConfigResponse.setGetClientConfigResult(config);
        return clientConfigResponse;
    }

    public GetBSConfigResponse getBSConfig(
            @WebParam(name = "GetBSConfig", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") GetBSConfig getBSConfig) {
        GetBSConfigResponse bsConfigResponse = new GetBSConfigResponse();
        BSConfigResponse configResponse = getConfigServiceDAO().getBSConfig(getBSConfig.getBs().getBSName());
        bsConfigResponse.setGetBSConfigResult(configResponse);
        return bsConfigResponse;
    }

    public GetOPSConfigResponse getOPSConfig(
            @WebParam(name = "GetOPSConfig", targetNamespace = "http://Trade.TraderConfigHost", partName =
                    "parameters") GetOPSConfig parameters) {
        OPSConfigResponse opsConfigResponse = getConfigServiceDAO().getOPSConfig(parameters.getOps().getOPSName());
        GetOPSConfigResponse getOPSConfigResponse = new GetOPSConfigResponse();
        getOPSConfigResponse.setGetOPSConfigResult(opsConfigResponse);
        return getOPSConfigResponse;
    }

    public SetClientToBSResponse setClientToBS(
            @WebParam(name = "SetClientToBS", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") SetClientToBS setClientToBS) {
        ClientToBS clientConfig = setClientToBS.getClientConfig();
        if (getConfigServiceDAO().setClientToBS(clientConfig.getClient(), clientConfig.getBs())) {
            return new SetClientToBSResponse();
        }
        return null;
    }

    public SetBSToOPSResponse setBSToOPS(
            @WebParam(name = "SetBSToOPS", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") SetBSToOPS setBSToOPS) {
        BSToOPS bsConfig = setBSToOPS.getBsConfig();
        if (getConfigServiceDAO().setBSToOPS(bsConfig.getBs(), bsConfig.getOps())) {
            return new SetBSToOPSResponse();
        }
        return null;
    }

    public GetBSLocationsResponse getBSLocations(
            @WebParam(name = "GetBSLocations", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") GetBSLocations getBSLocations) {
        final List<ServiceLocation> serviceLocations = getConfigServiceDAO().getBSLocations();
        GetBSLocationsResponse getBSLocationsResponse = new GetBSLocationsResponse();
        ArrayOfServiceLocation arrayOfServiceLocation = new ArrayOfServiceLocation();
        arrayOfServiceLocation.getServiceLocation().addAll(serviceLocations);
        getBSLocationsResponse.setGetBSLocationsResult(arrayOfServiceLocation);
        return getBSLocationsResponse;
    }

    public GetOPSLocationsResponse getOPSLocations(
            @WebParam(name = "GetOPSLocations", targetNamespace = "http://Trade.TraderConfigHost",
                    partName = "parameters") GetOPSLocations getOPSLocations) {
        List<ServiceLocation> serviceLocations = getConfigServiceDAO().getOPSLocations();
        GetOPSLocationsResponse response = new GetOPSLocationsResponse();
        ArrayOfServiceLocation arrayOfServiceLocation = new ArrayOfServiceLocation();
        arrayOfServiceLocation.getServiceLocation().addAll(serviceLocations);
        response.setGetOPSLocationsResult(arrayOfServiceLocation);
        return response;
    }

    public SetServiceLocationResponse setServiceLocation(
            @WebParam(name = "SetServiceLocation", targetNamespace = "http://Trade.TraderConfigHost", partName =
                    "parameters") SetServiceLocation parameters) {
        String serviceName = parameters.getLocation().getServiceName();
        String serviceUrl = parameters.getLocation().getServiceURL();
        Boolean isSec = parameters.getLocation().isSec();
        if (getConfigServiceDAO().setServiceLocation(serviceName, serviceUrl, isSec)) {
            return new SetServiceLocationResponse();
        }
        return null;
    }
}
