/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.stonehenge.stocktrader;

import java.math.BigDecimal;
import java.util.Calendar;

import com.ibm.websphere.samples.trade.OrderDataBean;

/**
 * This class is to be used as the data model for order information.
 */
public class CustomOrderBean extends OrderDataBean {

	private static final long serialVersionUID = 5294153874232419015L;

	int accountId;
	int holdingId;

	public CustomOrderBean(OrderDataBean orderDataBean) {
		setCompletionDate(orderDataBean.getCompletionDate());
		setOpenDate(orderDataBean.getOpenDate());
		setOrderFee(orderDataBean.getOrderFee());
		setOrderID(orderDataBean.getOrderID());
		setOrderStatus(orderDataBean.getOrderStatus());
		setOrderType(orderDataBean.getOrderType());
		setPrice(orderDataBean.getPrice());
		setQuantity(orderDataBean.getQuantity());
		setSymbol(orderDataBean.getSymbol());
	}

	public CustomOrderBean(int orderId, String orderType, String orderStatus,
			Calendar openDate, Calendar completionDate, double quantity,
			BigDecimal price, BigDecimal orderFee, String symbol) {
		setOrderID(orderId);
		setOrderType(orderType);
		setOrderStatus(orderStatus);
		setOpenDate(openDate);
		setCompletionDate(completionDate);
		setQuantity(quantity);
		setPrice(price);
		setOrderFee(orderFee);
		setSymbol(symbol);
	}

	/**
	 * Constructs data instance for order information.
	 * 
	 * @param accountId
	 *            the account ID of the buyer or seller
	 * @param holdingId
	 *            the ID of corresponding holding of the order
	 */
	public CustomOrderBean(int accountId, int holdingId) {
		this.accountId = accountId;
		this.holdingId = holdingId;
	}

	public int getAccountId() {
		return accountId;
	}

	public void setAccountId(int accountId) {
		this.accountId = accountId;
	}

	public int getHoldingId() {
		return holdingId;
	}

	public void setHoldingId(int holdingId) {
		this.holdingId = holdingId;
	}
}
